@@ -10,12 +10,13 @@ import logging
 import sys
 import zmq
 import time, json
-logging.basicConfig(format="%(levelname)s: %(message)s", level=logging.INFO)
+logging.basicConfig(format="%(asctime)s %(levelname)s: %(message)s", level=logging.INFO, datefmt='%Y-%m-%d %H:%M:%S')
+from aicmder.service import CLIENT_PORT
 
 # 3s for timeout
 REQUEST_TIMEOUT = 10000 #2500 
 REQUEST_RETRIES = 3
-SERVER_ENDPOINT = "tcp://localhost:5555"
+SERVER_ENDPOINT = f"tcp://localhost:{CLIENT_PORT}"
 
 context = zmq.Context()
 
